@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,55 +54,28 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 /* Substitute the variable and function names.  */
-#define yyparse stylecsssc_parse
-#define yylex   stylecsssc_lex
-#define yyerror stylecsssc_error
-#define yylval  stylecsssc_lval
-#define yychar  stylecsssc_char
-#define yydebug stylecsssc_debug
-#define yynerrs stylecsssc_nerrs
-
-
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     BOLD = 258,
-     ITALICS = 259,
-     UNDERLINE = 260,
-     FIXED = 261,
-     NOTFIXED = 262,
-     NOREF = 263,
-     KEY = 264,
-     COLOR = 265,
-     BG_COLOR = 266,
-     STRINGDEF = 267,
-     BG_STRINGDEF = 268
-   };
-#endif
-/* Tokens.  */
-#define BOLD 258
-#define ITALICS 259
-#define UNDERLINE 260
-#define FIXED 261
-#define NOTFIXED 262
-#define NOREF 263
-#define KEY 264
-#define COLOR 265
-#define BG_COLOR 266
-#define STRINGDEF 267
-#define BG_STRINGDEF 268
-
-
+#define yyparse         stylecsssc_parse
+#define yylex           stylecsssc_lex
+#define yyerror         stylecsssc_error
+#define yylval          stylecsssc_lval
+#define yychar          stylecsssc_char
+#define yydebug         stylecsssc_debug
+#define yynerrs         stylecsssc_nerrs
 
 
 /* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
 #line 1 "../../../lib/srchilite/stylecssparser.yy"
 
 /*
@@ -174,6 +146,9 @@ static string errorBuffer;
 
 
 
+/* Line 189 of yacc.c  */
+#line 151 "../../../lib/srchilite/stylecssparser.cc"
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -192,31 +167,71 @@ static string errorBuffer;
 # define YYTOKEN_TABLE 0
 #endif
 
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     BOLD = 258,
+     ITALICS = 259,
+     UNDERLINE = 260,
+     FIXED = 261,
+     NOTFIXED = 262,
+     NOREF = 263,
+     KEY = 264,
+     COLOR = 265,
+     BG_COLOR = 266,
+     STRINGDEF = 267,
+     BG_STRINGDEF = 268
+   };
+#endif
+/* Tokens.  */
+#define BOLD 258
+#define ITALICS 259
+#define UNDERLINE 260
+#define FIXED 261
+#define NOTFIXED 262
+#define NOREF 263
+#define KEY 264
+#define COLOR 265
+#define BG_COLOR 266
+#define STRINGDEF 267
+#define BG_STRINGDEF 268
+
+
+
+
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 70 "../../../lib/srchilite/stylecssparser.yy"
 {
+
+/* Line 214 of yacc.c  */
+#line 70 "../../../lib/srchilite/stylecssparser.yy"
+
   int tok ; /* command */
   const std::string * string ; /* string : id, ... */
   srchilite::StyleConstant flag ;
   srchilite::StyleConstants *styleconstants;
   srchilite::KeyList *keylist;
-}
-/* Line 187 of yacc.c.  */
-#line 207 "stylecssparser.cc"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 223 "../../../lib/srchilite/stylecssparser.cc"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 220 "stylecssparser.cc"
+/* Line 264 of yacc.c  */
+#line 235 "../../../lib/srchilite/stylecssparser.cc"
 
 #ifdef short
 # undef short
@@ -291,14 +306,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -379,9 +394,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -415,12 +430,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -519,7 +534,7 @@ static const char *const yytname[] =
   "$end", "error", "$undefined", "BOLD", "ITALICS", "UNDERLINE", "FIXED",
   "NOTFIXED", "NOREF", "KEY", "COLOR", "BG_COLOR", "STRINGDEF",
   "BG_STRINGDEF", "';'", "','", "$accept", "stylefile", "statements",
-  "statement", "option", "@1", "keylist", "optionspecs", "optionspec",
+  "statement", "option", "$@1", "keylist", "optionspecs", "optionspec",
   "color", "bgcolor", "styleconstant", 0
 };
 #endif
@@ -792,17 +807,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -836,11 +854,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1116,54 +1134,72 @@ yydestruct (yymsg, yytype, yyvaluep)
   switch (yytype)
     {
       case 9: /* "KEY" */
+
+/* Line 1000 of yacc.c  */
 #line 83 "../../../lib/srchilite/stylecssparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
 };
-#line 1125 "stylecssparser.cc"
+
+/* Line 1000 of yacc.c  */
+#line 1147 "../../../lib/srchilite/stylecssparser.cc"
 	break;
       case 10: /* "COLOR" */
+
+/* Line 1000 of yacc.c  */
 #line 83 "../../../lib/srchilite/stylecssparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
 };
-#line 1133 "stylecssparser.cc"
+
+/* Line 1000 of yacc.c  */
+#line 1159 "../../../lib/srchilite/stylecssparser.cc"
 	break;
       case 11: /* "BG_COLOR" */
+
+/* Line 1000 of yacc.c  */
 #line 83 "../../../lib/srchilite/stylecssparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
 };
-#line 1141 "stylecssparser.cc"
+
+/* Line 1000 of yacc.c  */
+#line 1171 "../../../lib/srchilite/stylecssparser.cc"
 	break;
       case 12: /* "STRINGDEF" */
+
+/* Line 1000 of yacc.c  */
 #line 83 "../../../lib/srchilite/stylecssparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
 };
-#line 1149 "stylecssparser.cc"
+
+/* Line 1000 of yacc.c  */
+#line 1183 "../../../lib/srchilite/stylecssparser.cc"
 	break;
       case 22: /* "keylist" */
+
+/* Line 1000 of yacc.c  */
 #line 83 "../../../lib/srchilite/stylecssparser.yy"
 	{
 	if ((yyvaluep->keylist))
 	  delete (yyvaluep->keylist);
 };
-#line 1157 "stylecssparser.cc"
+
+/* Line 1000 of yacc.c  */
+#line 1195 "../../../lib/srchilite/stylecssparser.cc"
 	break;
 
       default:
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1179,11 +1215,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1191,9 +1226,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1217,14 +1252,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1232,51 +1292,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1306,7 +1343,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1314,7 +1350,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1337,9 +1372,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1350,7 +1384,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1360,6 +1393,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1368,16 +1404,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1409,20 +1445,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1462,11 +1494,15 @@ yyreduce:
   switch (yyn)
     {
         case 2:
+
+/* Line 1455 of yacc.c  */
 #line 90 "../../../lib/srchilite/stylecssparser.yy"
     { /* allow empty files */ }
     break;
 
   case 7:
+
+/* Line 1455 of yacc.c  */
 #line 102 "../../../lib/srchilite/stylecssparser.yy"
     {
                //printSequence( $1 ) ;
@@ -1478,6 +1514,8 @@ yyreduce:
     break;
 
   case 8:
+
+/* Line 1455 of yacc.c  */
 #line 110 "../../../lib/srchilite/stylecssparser.yy"
     {
                KeyType key;
@@ -1513,6 +1551,8 @@ yyreduce:
     break;
 
   case 9:
+
+/* Line 1455 of yacc.c  */
 #line 144 "../../../lib/srchilite/stylecssparser.yy"
     {
               (yyvsp[(1) - (3)].keylist)->push_back(*(yyvsp[(3) - (3)].string));
@@ -1522,6 +1562,8 @@ yyreduce:
     break;
 
   case 10:
+
+/* Line 1455 of yacc.c  */
 #line 150 "../../../lib/srchilite/stylecssparser.yy"
     {
               (yyval.keylist) = new KeyList;
@@ -1531,11 +1573,15 @@ yyreduce:
     break;
 
   case 11:
+
+/* Line 1455 of yacc.c  */
 #line 157 "../../../lib/srchilite/stylecssparser.yy"
     {}
     break;
 
   case 16:
+
+/* Line 1455 of yacc.c  */
 #line 167 "../../../lib/srchilite/stylecssparser.yy"
     {
           currentColor = *(yyvsp[(1) - (1)].string);
@@ -1544,6 +1590,8 @@ yyreduce:
     break;
 
   case 17:
+
+/* Line 1455 of yacc.c  */
 #line 172 "../../../lib/srchilite/stylecssparser.yy"
     {
           currentColor = *(yyvsp[(1) - (1)].string);
@@ -1552,6 +1600,8 @@ yyreduce:
     break;
 
   case 18:
+
+/* Line 1455 of yacc.c  */
 #line 179 "../../../lib/srchilite/stylecssparser.yy"
     {
           currentBGColor = *(yyvsp[(1) - (1)].string);
@@ -1560,6 +1610,8 @@ yyreduce:
     break;
 
   case 19:
+
+/* Line 1455 of yacc.c  */
 #line 184 "../../../lib/srchilite/stylecssparser.yy"
     {
           currentBGColor = *(yyvsp[(1) - (1)].string);
@@ -1568,38 +1620,51 @@ yyreduce:
     break;
 
   case 20:
+
+/* Line 1455 of yacc.c  */
 #line 190 "../../../lib/srchilite/stylecssparser.yy"
     { currentStyleConstants->push_back(ISBOLD); }
     break;
 
   case 21:
+
+/* Line 1455 of yacc.c  */
 #line 191 "../../../lib/srchilite/stylecssparser.yy"
     { currentStyleConstants->push_back(ISITALIC); }
     break;
 
   case 22:
+
+/* Line 1455 of yacc.c  */
 #line 192 "../../../lib/srchilite/stylecssparser.yy"
     { currentStyleConstants->push_back(ISUNDERLINE); }
     break;
 
   case 23:
+
+/* Line 1455 of yacc.c  */
 #line 193 "../../../lib/srchilite/stylecssparser.yy"
     { currentStyleConstants->push_back(ISFIXED); }
     break;
 
   case 24:
+
+/* Line 1455 of yacc.c  */
 #line 194 "../../../lib/srchilite/stylecssparser.yy"
     { currentStyleConstants->push_back(ISNOTFIXED); }
     break;
 
   case 25:
+
+/* Line 1455 of yacc.c  */
 #line 195 "../../../lib/srchilite/stylecssparser.yy"
     { currentStyleConstants->push_back(ISNOREF); }
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1603 "stylecssparser.cc"
+
+/* Line 1455 of yacc.c  */
+#line 1668 "../../../lib/srchilite/stylecssparser.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1610,7 +1675,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1675,7 +1739,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1692,7 +1756,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1749,9 +1813,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -1776,7 +1837,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -1787,7 +1848,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -1813,6 +1874,8 @@ yyreturn:
 }
 
 
+
+/* Line 1675 of yacc.c  */
 #line 198 "../../../lib/srchilite/stylecssparser.yy"
 
 
